@@ -1,15 +1,15 @@
 package Perl::Critic::Policy::ValuesAndExpressions::ProhibitLeadingZeros;
 
-use 5.006001;
+use 5.010001;
 use strict;
 use warnings;
 
 use Readonly;
 
-use Perl::Critic::Utils qw{ :characters :severities };
-use base 'Perl::Critic::Policy';
+use Perl::Critic::Utils qw{ :characters :severities hashify };
+use parent 'Perl::Critic::Policy';
 
-our $VERSION = '1.126';
+our $VERSION = '1.148';
 
 #-----------------------------------------------------------------------------
 
@@ -43,6 +43,7 @@ sub violates {
     return $self->_create_violation($elem) if $self->{_strict};
     return if $self->_is_first_argument_of_chmod_or_umask($elem);
     return if $self->_is_second_argument_of_mkdir($elem);
+    return if $self->_is_second_argument_of_mkfifo($elem);
     return if $self->_is_third_argument_of_dbmopen($elem);
     return if $self->_is_fourth_argument_of_sysopen($elem);
     return $self->_create_violation($elem);
@@ -88,6 +89,27 @@ sub _is_second_argument_of_mkdir {
     return $previous_token->content() eq 'mkdir';
 }
 
+sub _is_second_argument_of_mkfifo {
+    my ($self, $elem) = @_;
+
+    # Preceding comma.
+    my $previous_token = _previous_token_that_isnt_a_parenthesis($elem);
+    return if not $previous_token;
+    return if $previous_token->content() ne $COMMA;  # Don't know what it is.
+
+    # FIFO name.
+    $previous_token =
+        _previous_token_that_isnt_a_parenthesis($previous_token);
+    return if not $previous_token;
+
+    $previous_token =
+        _previous_token_that_isnt_a_parenthesis($previous_token);
+    return if not $previous_token;
+
+    state $is_mkfifo = { hashify( 'mkfifo', 'POSIX::mkfifo' ) };
+    return $is_mkfifo->{$previous_token->content()};
+}
+
 sub _is_third_argument_of_dbmopen {
     my ($self, $elem) = @_;
 
@@ -157,19 +179,27 @@ sub _is_fourth_argument_of_sysopen {
         _previous_token_that_isnt_a_parenthesis($previous_token);
     return if not $previous_token;
 
+    # GitHub #789
+    if ( $previous_token->content() eq 'my' ) {
+        $previous_token = _previous_token_that_isnt_a_parenthesis(
+            $previous_token );
+        return if not $previous_token;
+    }
+
     return $previous_token->content() eq 'sysopen';
 }
 
 sub _previous_token_that_isnt_a_parenthesis {
     my ($elem) = @_;
 
+    state $is_paren = { hashify( $LEFT_PAREN, $RIGHT_PAREN ) };
+
     my $previous_token = $elem->previous_token();
     while (
             $previous_token
         and (
                 not $previous_token->significant()
-            or  $previous_token->content() eq $LEFT_PAREN
-            or  $previous_token->content() eq $RIGHT_PAREN
+            or  $is_paren->{$previous_token->content()}
         )
     ) {
         $previous_token = $previous_token->previous_token();
@@ -211,6 +241,10 @@ you really want, its better to use C<oct> and make it obvious.
     sysopen $filehandle, $filename, O_RDWR, 0666;   # ok by default
     umask 0002;                                     # ok by default
 
+    use POSIX 'mkfifo';
+    mkfifo $fifo, 0600;                             # ok by default
+    POSIX::mkfifo $fifo, 0600;                      # ok by default
+
 =head1 CONFIGURATION
 
 If you want to ban all leading zeros, set C<strict> to a true value in
@@ -226,7 +260,7 @@ Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2011 Imaginative Software Systems.  All rights reserved.
+Copyright (c) 2005-2023 Imaginative Software Systems.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
